# Security Policy

## Supported Versions

We only support the latest major version and each subversion.

| Version  | Supported          |
| -------- | ------------------ |
| 10.0.x   | :white_check_mark: |
| < 10.0   | :x:                |

